@@ -22,6 +22,7 @@ import (
 	"github.com/trufflesecurity/trufflehog/v3/pkg/context"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/decoders"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/engine"
+	"github.com/trufflesecurity/trufflehog/v3/pkg/handlers"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/log"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/output"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/sources"
@@ -46,6 +47,11 @@ var (
 	printAvgDetectorTime = cli.Flag("print-avg-detector-time", "Print the average time spent on each detector.").Bool()
 	noUpdate             = cli.Flag("no-update", "Don't check for updates.").Bool()
 	fail                 = cli.Flag("fail", "Exit with code 183 if results are found.").Bool()
+	archiveMaxSize       = cli.Flag("archive-max-size", "Maximum size of archive to scan.").Bytes()
+	archiveMaxDepth      = cli.Flag("archive-max-depth", "Maximum depth of archive to scan.").Int()
+	archiveTimeout       = cli.Flag("archive-timeout", "Maximum time to spend extracting an archive.").Duration()
+	includeDetectors     = cli.Flag("include-detectors", "Comma separated list of detector types to include. Types must exist in detectors.proto").String()
+	excludeDetectors     = cli.Flag("exclude-detectors", "Comma separated list of detector types to exclude. Types must exist in detectors.proto").String()
 
 	gitScan             = cli.Command("git", "Find credentials in git repositories.")
 	gitScanURI          = gitScan.Arg("uri", "Git repository URL. https://, file://, or ssh:// schema expected.").Required().String()
@@ -178,7 +184,11 @@ func run(state overseer.State) {
 			}
 		}()
 	}
-	logger, sync := log.New("trufflehog", log.WithConsoleSink(os.Stderr))
+	logFormat := log.WithConsoleSink
+	if *jsonOut {
+		logFormat = log.WithJSONSink
+	}
+	logger, sync := log.New("trufflehog", logFormat(os.Stderr))
 	context.SetDefaultLogger(logger)
 	defer func() { _ = sync() }()
 
@@ -192,13 +202,42 @@ func run(state overseer.State) {
 		}
 	}
 
+	if *archiveMaxSize != 0 {
+		handlers.SetArchiveMaxSize(int(*archiveMaxSize))
+	}
+	if *archiveMaxDepth != 0 {
+		handlers.SetArchiveMaxDepth(*archiveMaxDepth)
+	}
+	if *archiveTimeout != 0 {
+		handlers.SetArchiveMaxTimeout(*archiveTimeout)
+	}
+
 	ctx := context.TODO()
+	var detectorsOption engine.EngineOption
+
+	detectorCfg, err := engine.NewDetectorsConfig(*includeDetectors, *excludeDetectors)
+	if err != nil {
+		logger.Error(err, "failed to create detectors config")
+		os.Exit(1)
+	}
+	dts, err := engine.Detectors(ctx, detectorCfg)
+	if err != nil {
+		logger.Error(err, "failed to create detectors")
+		os.Exit(1)
+	}
+
+	if len(dts) > 0 {
+		detectorsOption = engine.WithDetectors(!*noVerification, dts...)
+	} else {
+		detectorsOption = engine.WithDetectors(!*noVerification, engine.DefaultDetectors()...)
+	}
+
 	e := engine.Start(ctx,
 		engine.WithConcurrency(*concurrency),
 		engine.WithDecoders(decoders.DefaultDecoders()...),
-		engine.WithDetectors(!*noVerification, engine.DefaultDetectors()...),
 		engine.WithDetectors(!*noVerification, conf.Detectors...),
 		engine.WithFilterUnverified(*filterUnverified),
+		detectorsOption,
 	)
 
 	var repoPath string
@@ -217,15 +256,14 @@ func run(state overseer.State) {
 			defer os.RemoveAll(repoPath)
 		}
 
-		g := func(c *sources.Config) {
-			c.RepoPath = repoPath
-			c.HeadRef = *gitScanBranch
-			c.BaseRef = *gitScanSinceCommit
-			c.MaxDepth = *gitScanMaxDepth
-			c.Filter = filter
+		cfg := sources.GitConfig{
+			RepoPath: repoPath,
+			HeadRef:  *gitScanBranch,
+			BaseRef:  *gitScanSinceCommit,
+			MaxDepth: *gitScanMaxDepth,
+			Filter:   filter,
 		}
-
-		if err = e.ScanGit(ctx, sources.NewConfig(g)); err != nil {
+		if err = e.ScanGit(ctx, cfg); err != nil {
 			logrus.WithError(err).Fatal("Failed to scan Git.")
 		}
 	case githubScan.FullCommand():
@@ -233,19 +271,18 @@ func run(state overseer.State) {
 			logrus.Fatal("You must specify at least one organization or repository.")
 		}
 
-		github := func(c *sources.Config) {
-			c.Endpoint = *githubScanEndpoint
-			c.Repos = *githubScanRepos
-			c.Orgs = *githubScanOrgs
-			c.Token = *githubScanToken
-			c.IncludeForks = *githubIncludeForks
-			c.IncludeMembers = *githubIncludeMembers
-			c.Concurrency = *concurrency
-			c.ExcludeRepos = *githubExcludeRepos
-			c.IncludeRepos = *githubIncludeRepos
+		cfg := sources.GithubConfig{
+			Endpoint:       *githubScanEndpoint,
+			Token:          *githubScanToken,
+			IncludeForks:   *githubIncludeForks,
+			IncludeMembers: *githubIncludeMembers,
+			Concurrency:    *concurrency,
+			ExcludeRepos:   *githubExcludeRepos,
+			IncludeRepos:   *githubIncludeRepos,
+			Repos:          *githubScanRepos,
+			Orgs:           *githubScanOrgs,
 		}
-
-		if err := e.ScanGitHub(ctx, sources.NewConfig(github)); err != nil {
+		if err := e.ScanGitHub(ctx, cfg); err != nil {
 			logrus.WithError(err).Fatal("Failed to scan Github.")
 		}
 	case gitlabScan.FullCommand():
@@ -254,14 +291,13 @@ func run(state overseer.State) {
 			logrus.WithError(err).Fatal("could not create filter")
 		}
 
-		gitlab := func(c *sources.Config) {
-			c.Endpoint = *gitlabScanEndpoint
-			c.Token = *gitlabScanToken
-			c.Repos = *gitlabScanRepos
-			c.Filter = filter
+		cfg := sources.GitlabConfig{
+			Endpoint: *gitlabScanEndpoint,
+			Token:    *gitlabScanToken,
+			Repos:    *gitlabScanRepos,
+			Filter:   filter,
 		}
-
-		if err := e.ScanGitLab(ctx, sources.NewConfig(gitlab)); err != nil {
+		if err := e.ScanGitLab(ctx, cfg); err != nil {
 			logrus.WithError(err).Fatal("Failed to scan GitLab.")
 		}
 	case filesystemScan.FullCommand():
@@ -270,35 +306,33 @@ func run(state overseer.State) {
 			logrus.WithError(err).Fatal("could not create filter")
 		}
 
-		fs := func(c *sources.Config) {
-			c.Directories = *filesystemDirectories
-			c.Filter = filter
+		cfg := sources.FilesystemConfig{
+			Directories: *filesystemDirectories,
+			Filter:      filter,
 		}
-
-		if err = e.ScanFileSystem(ctx, sources.NewConfig(fs)); err != nil {
+		if err = e.ScanFileSystem(ctx, cfg); err != nil {
 			logrus.WithError(err).Fatal("Failed to scan filesystem")
 		}
 	case s3Scan.FullCommand():
-		s3 := func(c *sources.Config) {
-			c.Key = *s3ScanKey
-			c.Secret = *s3ScanSecret
-			c.Buckets = *s3ScanBuckets
+		cfg := sources.S3Config{
+			Key:       *s3ScanKey,
+			Secret:    *s3ScanSecret,
+			Buckets:   *s3ScanBuckets,
+			CloudCred: *s3ScanCloudEnv,
 		}
-
-		if err := e.ScanS3(ctx, sources.NewConfig(s3)); err != nil {
+		if err := e.ScanS3(ctx, cfg); err != nil {
 			logrus.WithError(err).Fatal("Failed to scan S3.")
 		}
 	case syslogScan.FullCommand():
-		syslog := func(c *sources.Config) {
-			c.Address = *syslogAddress
-			c.Protocol = *syslogProtocol
-			c.CertPath = *syslogTLSCert
-			c.KeyPath = *syslogTLSKey
-			c.Format = *syslogFormat
-			c.Concurrency = *concurrency
+		cfg := sources.SyslogConfig{
+			Address:     *syslogAddress,
+			Format:      *syslogFormat,
+			Protocol:    *syslogProtocol,
+			CertPath:    *syslogTLSCert,
+			KeyPath:     *syslogTLSKey,
+			Concurrency: *concurrency,
 		}
-
-		if err := e.ScanSyslog(ctx, sources.NewConfig(syslog)); err != nil {
+		if err := e.ScanSyslog(ctx, cfg); err != nil {
 			logrus.WithError(err).Fatal("Failed to scan syslog.")
 		}
 	case circleCiScan.FullCommand():
