@@ -44,68 +44,89 @@ type Source interface {
 	GetProgress() *Progress
 }
 
-// Config defines the optional configuration for a source.
-type Config struct {
-	// Endpoint is the endpoint of the source.
-	Endpoint,
-	// Repo is the repository to scan.
-	Repo,
-	// Token is the token to use to authenticate with the source.
-	Token,
-	// Key is any key to use to authenticate with the source. (ex: S3)
-	Key,
-	// Secret is any secret to use to authenticate with the source. (ex: S3)
-	Secret,
-	// Address used to connect to the source. (ex: syslog)
-	Address,
-	// Protocol used to connect to the source.
-	Protocol,
-	// CertPath is the path to the certificate to use to connect to the source.
-	CertPath,
-	// KeyPath is the path to the key to use to connect to the source.
-	KeyPath,
-	// Format is the format used to connect to the source.
-	Format,
+// GitConfig defines the optional configuration for a git source.
+type GitConfig struct {
 	// RepoPath is the path to the repository to scan.
 	RepoPath,
 	// HeadRef is the head reference to use to scan from.
 	HeadRef,
 	// BaseRef is the base reference to use to scan from.
 	BaseRef string
-	// Concurrency is the number of concurrent workers to use to scan the source.
-	Concurrency,
 	// MaxDepth is the maximum depth to scan the source.
 	MaxDepth int
+	// Filter is the filter to use to scan the source.
+	Filter *common.Filter
+}
+
+// GithubConfig defines the optional configuration for a github source.
+type GithubConfig struct {
+	// Endpoint is the endpoint of the source.
+	Endpoint,
+	// Token is the token to use to authenticate with the source.
+	Token string
 	// IncludeForks indicates whether to include forks in the scan.
 	IncludeForks,
 	// IncludeMembers indicates whether to include members in the scan.
-	IncludeMembers,
-	// CloudCred determines whether to use cloud credentials.
-	// This can NOT be used with a secret.
-	CloudCred bool
+	IncludeMembers bool
+	// Concurrency is the number of concurrent workers to use to scan the source.
+	Concurrency int
 	// Repos is the list of repositories to scan.
 	Repos,
 	// Orgs is the list of organizations to scan.
 	Orgs,
-	// Buckets is the list of buckets to scan.
-	Buckets,
 	// ExcludeRepos is a list of repositories to exclude from the scan.
 	ExcludeRepos,
 	// IncludeRepos is a list of repositories to include in the scan.
-	IncludeRepos,
+	IncludeRepos []string
+}
+
+// GitlabConfig defines the optional configuration for a gitlab source.
+type GitlabConfig struct {
+	// Endpoint is the endpoint of the source.
+	Endpoint,
+	// Token is the token to use to authenticate with the source.
+	Token string
+	// Repos is the list of repositories to scan.
+	Repos []string
+	// Filter is the filter to use to scan the source.
+	Filter *common.Filter
+}
+
+// FilesystemConfig defines the optional configuration for a filesystem source.
+type FilesystemConfig struct {
 	// Directories is the list of directories to scan.
 	Directories []string
 	// Filter is the filter to use to scan the source.
 	Filter *common.Filter
 }
 
-// NewConfig returns a new Config with optional values.
-func NewConfig(opts ...func(*Config)) Config {
-	c := &Config{}
-	for _, opt := range opts {
-		opt(c)
-	}
-	return *c
+// S3Config defines the optional configuration for an S3 source.
+type S3Config struct {
+	// CloudCred determines whether to use cloud credentials.
+	// This can NOT be used with a secret.
+	CloudCred bool
+	// Key is any key to use to authenticate with the source.
+	Key,
+	// Secret is any secret to use to authenticate with the source.
+	Secret string
+	// Buckets is the list of buckets to scan.
+	Buckets []string
+}
+
+// SyslogConfig defines the optional configuration for a syslog source.
+type SyslogConfig struct {
+	// Address used to connect to the source.
+	Address,
+	// Protocol used to connect to the source.
+	Protocol,
+	// CertPath is the path to the certificate to use to connect to the source.
+	CertPath,
+	// Format is the format used to connect to the source.
+	Format,
+	// KeyPath is the path to the key to use to connect to the source.
+	KeyPath string
+	// Concurrency is the number of concurrent workers to use to scan the source.
+	Concurrency int
 }
 
 // Progress is used to update job completion progress across sources.
